@@ -3,7 +3,7 @@ import logging
 from typing import Dict
 
 from aliyunsdkrds.request.v20140815 import DescribeDBInstancesRequest, DescribeDBInstanceAttributeRequest, DescribeResourceUsageRequest, \
-    DescribeBackupsRequest, CreateBackupRequest, DescribeBackupTasksRequest, CreateDBInstanceRequest, ModifySecurityIpsRequest
+    DescribeBackupsRequest, CreateBackupRequest, DescribeBackupTasksRequest, CreateDBInstanceRequest, ModifySecurityIpsRequest,TransformDBInstancePayTypeRequest
 
 from aliyunsdkrds.endpoint import endpoint_data
 
@@ -183,4 +183,35 @@ class RDS(AliClient):
         ret = self.do_action(request)
         return ret
 
+
+    def updatePayTypeInstance(self,id,paytype,period,usedtime=1):
+        """调用TransformDBInstancePayType接口变更RDS实例的计费方式。
+
+        :param id:
+            实例ID。
+        :param paytype:
+            实例的付费类型。取值：
+                Postpaid：后付费（按量付费）
+                Prepaid：预付费（包年包月）
+        :param period:
+            指定预付费实例为包年或者包月类型。取值：
+                Year：包年
+                Month：包月
+            说明 若PayType=Prepaid，需要传入该参数。
+        :param usedtime:
+            指定购买时长。取值：
+                当参数Period为Year时，UsedTime取值为1~5。
+                当参数Period为Month时，UsedTime取值为1~9。
+            说明 若PayType=Prepaid，需要传入该参数。
+        :return:
+        """
+        request =TransformDBInstancePayTypeRequest.TransformDBInstancePayTypeRequest()
+        request.set_DBInstanceId(id)
+        request.set_PayType(paytype)
+        request.set_Period(period)
+        request.set_UsedTime(usedtime)
+        ret = self.do_action(request)
+        return ret
+
+
 endpoint_map = endpoint_data.endpoint_map
\ No newline at end of file
